==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/saas/kotlin/inputs/SaasCreationPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.saas.kotlin.inputs

import com.pulumi.azurenative.saas.inputs.SaasCreationPropertiesArgs.builder
import com.pulumi.azurenative.saas.kotlin.enums.PaymentChannelType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Double
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * properties for creation saas
 * @property autoRenew Whether the SaaS subscription will auto renew upon term end.
 * @property offerId The offer id.
 * @property paymentChannelMetadata The metadata about the SaaS subscription such as the AzureSubscriptionId and ResourceUri.
 * @property paymentChannelType The Payment channel for the SaasSubscription.
 * @property publisherId The publisher id.
 * @property publisherTestEnvironment The environment in the publisher side for this resource.
 * @property quantity The seat count.
 * @property saasResourceName The SaaS resource name.
 * @property saasSessionId The saas session id used for dev service migration request.
 * @property saasSubscriptionId The saas subscription id used for tenant to subscription level migration request.
 * @property skuId The plan id.
 * @property termId The current Term id.
 */
public data class SaasCreationPropertiesArgs(
    public val autoRenew: Output<Boolean>? = null,
    public val offerId: Output<String>? = null,
    public val paymentChannelMetadata: Output<Map<String, String>>? = null,
    public val paymentChannelType: Output<Either<String, PaymentChannelType>>? = null,
    public val publisherId: Output<String>? = null,
    public val publisherTestEnvironment: Output<String>? = null,
    public val quantity: Output<Double>? = null,
    public val saasResourceName: Output<String>? = null,
    public val saasSessionId: Output<String>? = null,
    public val saasSubscriptionId: Output<String>? = null,
    public val skuId: Output<String>? = null,
    public val termId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.saas.inputs.SaasCreationPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.saas.inputs.SaasCreationPropertiesArgs =
        com.pulumi.azurenative.saas.inputs.SaasCreationPropertiesArgs.builder()
            .autoRenew(autoRenew?.applyValue({ args0 -> args0 }))
            .offerId(offerId?.applyValue({ args0 -> args0 }))
            .paymentChannelMetadata(
                paymentChannelMetadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .paymentChannelType(
                paymentChannelType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .publisherId(publisherId?.applyValue({ args0 -> args0 }))
            .publisherTestEnvironment(publisherTestEnvironment?.applyValue({ args0 -> args0 }))
            .quantity(quantity?.applyValue({ args0 -> args0 }))
            .saasResourceName(saasResourceName?.applyValue({ args0 -> args0 }))
            .saasSessionId(saasSessionId?.applyValue({ args0 -> args0 }))
            .saasSubscriptionId(saasSubscriptionId?.applyValue({ args0 -> args0 }))
            .skuId(skuId?.applyValue({ args0 -> args0 }))
            .termId(termId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SaasCreationPropertiesArgs].
 */
@PulumiTagMarker
public class SaasCreationPropertiesArgsBuilder internal constructor() {
    private var autoRenew: Output<Boolean>? = null

    private var offerId: Output<String>? = null

    private var paymentChannelMetadata: Output<Map<String, String>>? = null

    private var paymentChannelType: Output<Either<String, PaymentChannelType>>? = null

    private var publisherId: Output<String>? = null

    private var publisherTestEnvironment: Output<String>? = null

    private var quantity: Output<Double>? = null

    private var saasResourceName: Output<String>? = null

    private var saasSessionId: Output<String>? = null

    private var saasSubscriptionId: Output<String>? = null

    private var skuId: Output<String>? = null

    private var termId: Output<String>? = null

    /**
     * @param value Whether the SaaS subscription will auto renew upon term end.
     */
    @JvmName("kxwsdmwssboyvvuw")
    public suspend fun autoRenew(`value`: Output<Boolean>) {
        this.autoRenew = value
    }

    /**
     * @param value The offer id.
     */
    @JvmName("dpbbrpvfkcbiljdb")
    public suspend fun offerId(`value`: Output<String>) {
        this.offerId = value
    }

    /**
     * @param value The metadata about the SaaS subscription such as the AzureSubscriptionId and ResourceUri.
     */
    @JvmName("okgrrygjxfdgnjie")
    public suspend fun paymentChannelMetadata(`value`: Output<Map<String, String>>) {
        this.paymentChannelMetadata = value
    }

    /**
     * @param value The Payment channel for the SaasSubscription.
     */
    @JvmName("dohakqpqhkvageey")
    public suspend fun paymentChannelType(`value`: Output<Either<String, PaymentChannelType>>) {
        this.paymentChannelType = value
    }

    /**
     * @param value The publisher id.
     */
    @JvmName("krigedlfaklrwjwe")
    public suspend fun publisherId(`value`: Output<String>) {
        this.publisherId = value
    }

    /**
     * @param value The environment in the publisher side for this resource.
     */
    @JvmName("difvjvlkjaqwpbmi")
    public suspend fun publisherTestEnvironment(`value`: Output<String>) {
        this.publisherTestEnvironment = value
    }

    /**
     * @param value The seat count.
     */
    @JvmName("hefywfvvcjsjpnjr")
    public suspend fun quantity(`value`: Output<Double>) {
        this.quantity = value
    }

    /**
     * @param value The SaaS resource name.
     */
    @JvmName("crxrgkiaghjgkseq")
    public suspend fun saasResourceName(`value`: Output<String>) {
        this.saasResourceName = value
    }

    /**
     * @param value The saas session id used for dev service migration request.
     */
    @JvmName("pyofxpgbhjaxrmss")
    public suspend fun saasSessionId(`value`: Output<String>) {
        this.saasSessionId = value
    }

    /**
     * @param value The saas subscription id used for tenant to subscription level migration request.
     */
    @JvmName("ruknacqydwgnapnq")
    public suspend fun saasSubscriptionId(`value`: Output<String>) {
        this.saasSubscriptionId = value
    }

    /**
     * @param value The plan id.
     */
    @JvmName("haxlsfxfprorvtbk")
    public suspend fun skuId(`value`: Output<String>) {
        this.skuId = value
    }

    /**
     * @param value The current Term id.
     */
    @JvmName("brvuqkimnpshyswj")
    public suspend fun termId(`value`: Output<String>) {
        this.termId = value
    }

    /**
     * @param value Whether the SaaS subscription will auto renew upon term end.
     */
    @JvmName("wghouuuagfdyxonn")
    public suspend fun autoRenew(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoRenew = mapped
    }

    /**
     * @param value The offer id.
     */
    @JvmName("plqosnmdmtafabrq")
    public suspend fun offerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.offerId = mapped
    }

    /**
     * @param value The metadata about the SaaS subscription such as the AzureSubscriptionId and ResourceUri.
     */
    @JvmName("rdqlgjoysexiskyc")
    public suspend fun paymentChannelMetadata(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.paymentChannelMetadata = mapped
    }

    /**
     * @param values The metadata about the SaaS subscription such as the AzureSubscriptionId and ResourceUri.
     */
    @JvmName("gbjmilkwklknqcev")
    public fun paymentChannelMetadata(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paymentChannelMetadata = mapped
    }

    /**
     * @param value The Payment channel for the SaasSubscription.
     */
    @JvmName("pkakhqsubwpaxjkp")
    public suspend fun paymentChannelType(`value`: Either<String, PaymentChannelType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.paymentChannelType = mapped
    }

    /**
     * @param value The Payment channel for the SaasSubscription.
     */
    @JvmName("fmjredscupcpjvud")
    public fun paymentChannelType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PaymentChannelType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paymentChannelType = mapped
    }

    /**
     * @param value The Payment channel for the SaasSubscription.
     */
    @JvmName("kjxqngddpuabckeo")
    public fun paymentChannelType(`value`: PaymentChannelType) {
        val toBeMapped = Either.ofRight<String, PaymentChannelType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paymentChannelType = mapped
    }

    /**
     * @param value The publisher id.
     */
    @JvmName("ovrbhfcaimdntltn")
    public suspend fun publisherId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisherId = mapped
    }

    /**
     * @param value The environment in the publisher side for this resource.
     */
    @JvmName("xhvhenadiywwjnjw")
    public suspend fun publisherTestEnvironment(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisherTestEnvironment = mapped
    }

    /**
     * @param value The seat count.
     */
    @JvmName("rnicjogdwjxspswy")
    public suspend fun quantity(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.quantity = mapped
    }

    /**
     * @param value The SaaS resource name.
     */
    @JvmName("agmljumgvotfkflj")
    public suspend fun saasResourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.saasResourceName = mapped
    }

    /**
     * @param value The saas session id used for dev service migration request.
     */
    @JvmName("qfvfmgddmelmxjlu")
    public suspend fun saasSessionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.saasSessionId = mapped
    }

    /**
     * @param value The saas subscription id used for tenant to subscription level migration request.
     */
    @JvmName("xsdkqywigbbrgeox")
    public suspend fun saasSubscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.saasSubscriptionId = mapped
    }

    /**
     * @param value The plan id.
     */
    @JvmName("licutsapmqrcfdfn")
    public suspend fun skuId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.skuId = mapped
    }

    /**
     * @param value The current Term id.
     */
    @JvmName("csunetxxskojfxho")
    public suspend fun termId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.termId = mapped
    }

    internal fun build(): SaasCreationPropertiesArgs = SaasCreationPropertiesArgs(
        autoRenew = autoRenew,
        offerId = offerId,
        paymentChannelMetadata = paymentChannelMetadata,
        paymentChannelType = paymentChannelType,
        publisherId = publisherId,
        publisherTestEnvironment = publisherTestEnvironment,
        quantity = quantity,
        saasResourceName = saasResourceName,
        saasSessionId = saasSessionId,
        saasSubscriptionId = saasSubscriptionId,
        skuId = skuId,
        termId = termId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/saas/kotlin/inputs/SaasCreationPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.saas.kotlin.inputs

import com.pulumi.azurenative.saas.inputs.SaasCreationPropertiesArgs.builder
import com.pulumi.azurenative.saas.kotlin.enums.PaymentChannelType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Double
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * properties for creation saas
 * @property autoRenew Whether the SaaS subscription will auto renew upon term end.
 * @property offerId The offer id.
 * @property paymentChannelMetadata The metadata about the SaaS subscription such as the AzureSubscriptionId and ResourceUri.
 * @property paymentChannelType The Payment channel for the SaasSubscription.
 * @property publisherId The publisher id.
 * @property publisherTestEnvironment The environment in the publisher side for this resource.
 * @property quantity The seat count.
 * @property saasResourceName The SaaS resource name.
 * @property saasSessionId The saas session id used for dev service migration request.
 * @property saasSubscriptionId The saas subscription id used for tenant to subscription level migration request.
 * @property skuId The plan id.
 * @property termId The current Term id.
 */
public data class SaasCreationPropertiesArgs(
    public val autoRenew: Output<Boolean>? = null,
    public val offerId: Output<String>? = null,
    public val paymentChannelMetadata: Output<Map<String, String>>? = null,
    public val paymentChannelType: Output<Either<String, PaymentChannelType>>? = null,
    public val publisherId: Output<String>? = null,
    public val publisherTestEnvironment: Output<String>? = null,
    public val quantity: Output<Double>? = null,
    public val saasResourceName: Output<String>? = null,
    public val saasSessionId: Output<String>? = null,
    public val saasSubscriptionId: Output<String>? = null,
    public val skuId: Output<String>? = null,
    public val termId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.saas.inputs.SaasCreationPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.saas.inputs.SaasCreationPropertiesArgs =
        com.pulumi.azurenative.saas.inputs.SaasCreationPropertiesArgs.builder()
            .autoRenew(autoRenew?.applyValue({ args0 -> args0 }))
            .offerId(offerId?.applyValue({ args0 -> args0 }))
            .paymentChannelMetadata(
                paymentChannelMetadata?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .paymentChannelType(
                paymentChannelType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .publisherId(publisherId?.applyValue({ args0 -> args0 }))
            .publisherTestEnvironment(publisherTestEnvironment?.applyValue({ args0 -> args0 }))
            .quantity(quantity?.applyValue({ args0 -> args0 }))
            .saasResourceName(saasResourceName?.applyValue({ args0 -> args0 }))
            .saasSessionId(saasSessionId?.applyValue({ args0 -> args0 }))
            .saasSubscriptionId(saasSubscriptionId?.applyValue({ args0 -> args0 }))
            .skuId(skuId?.applyValue({ args0 -> args0 }))
            .termId(termId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SaasCreationPropertiesArgs].
 */
@PulumiTagMarker
public class SaasCreationPropertiesArgsBuilder internal constructor() {
    private var autoRenew: Output<Boolean>? = null

    private var offerId: Output<String>? = null

    private var paymentChannelMetadata: Output<Map<String, String>>? = null

    private var paymentChannelType: Output<Either<String, PaymentChannelType>>? = null

    private var publisherId: Output<String>? = null

    private var publisherTestEnvironment: Output<String>? = null

    private var quantity: Output<Double>? = null

    private var saasResourceName: Output<String>? = null

    private var saasSessionId: Output<String>? = null

    private var saasSubscriptionId: Output<String>? = null

    private var skuId: Output<String>? = null

    private var termId: Output<String>? = null

    /**
     * @param value Whether the SaaS subscription will auto renew upon term end.
     */
    @JvmName("cpsenjtnswnhjlpk")
    public suspend fun autoRenew(`value`: Output<Boolean>) {
        this.autoRenew = value
    }

    /**
     * @param value The offer id.
     */
    @JvmName("qybeaafetgnbwhtf")
    public suspend fun offerId(`value`: Output<String>) {
        this.offerId = value
    }

    /**
     * @param value The metadata about the SaaS subscription such as the AzureSubscriptionId and ResourceUri.
     */
    @JvmName("hqkglwwsowjtpcqp")
    public suspend fun paymentChannelMetadata(`value`: Output<Map<String, String>>) {
        this.paymentChannelMetadata = value
    }

    /**
     * @param value The Payment channel for the SaasSubscription.
     */
    @JvmName("nlmqrwjbhuiifgtv")
    public suspend fun paymentChannelType(`value`: Output<Either<String, PaymentChannelType>>) {
        this.paymentChannelType = value
    }

    /**
     * @param value The publisher id.
     */
    @JvmName("wqhiuigpuggfidvc")
    public suspend fun publisherId(`value`: Output<String>) {
        this.publisherId = value
    }

    /**
     * @param value The environment in the publisher side for this resource.
     */
    @JvmName("ppqygnhilojldyil")
    public suspend fun publisherTestEnvironment(`value`: Output<String>) {
        this.publisherTestEnvironment = value
    }

    /**
     * @param value The seat count.
     */
    @JvmName("teftvidkqbeexofc")
    public suspend fun quantity(`value`: Output<Double>) {
        this.quantity = value
    }

    /**
     * @param value The SaaS resource name.
     */
    @JvmName("lniwcpqkcrpxwste")
    public suspend fun saasResourceName(`value`: Output<String>) {
        this.saasResourceName = value
    }

    /**
     * @param value The saas session id used for dev service migration request.
     */
    @JvmName("xrwxvytwagmehmyj")
    public suspend fun saasSessionId(`value`: Output<String>) {
        this.saasSessionId = value
    }

    /**
     * @param value The saas subscription id used for tenant to subscription level migration request.
     */
    @JvmName("wykvbjudluegsegs")
    public suspend fun saasSubscriptionId(`value`: Output<String>) {
        this.saasSubscriptionId = value
    }

    /**
     * @param value The plan id.
     */
    @JvmName("gvuhnrgqjoewxcfa")
    public suspend fun skuId(`value`: Output<String>) {
        this.skuId = value
    }

    /**
     * @param value The current Term id.
     */
    @JvmName("tvisrtxvyaayohrj")
    public suspend fun termId(`value`: Output<String>) {
        this.termId = value
    }

    /**
     * @param value Whether the SaaS subscription will auto renew upon term end.
     */
    @JvmName("paggacyemctjrily")
    public suspend fun autoRenew(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoRenew = mapped
    }

    /**
     * @param value The offer id.
     */
    @JvmName("qrymmfuehgkdpbly")
    public suspend fun offerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.offerId = mapped
    }

    /**
     * @param value The metadata about the SaaS subscription such as the AzureSubscriptionId and ResourceUri.
     */
    @JvmName("qdemjnignphqorju")
    public suspend fun paymentChannelMetadata(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.paymentChannelMetadata = mapped
    }

    /**
     * @param values The metadata about the SaaS subscription such as the AzureSubscriptionId and ResourceUri.
     */
    @JvmName("vkbwblwdpfcqmapu")
    public fun paymentChannelMetadata(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paymentChannelMetadata = mapped
    }

    /**
     * @param value The Payment channel for the SaasSubscription.
     */
    @JvmName("srbfotxfcnqtwlly")
    public suspend fun paymentChannelType(`value`: Either<String, PaymentChannelType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.paymentChannelType = mapped
    }

    /**
     * @param value The Payment channel for the SaasSubscription.
     */
    @JvmName("ikydulyiuiwgtfpv")
    public fun paymentChannelType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PaymentChannelType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paymentChannelType = mapped
    }

    /**
     * @param value The Payment channel for the SaasSubscription.
     */
    @JvmName("xhvpfidtqareyluc")
    public fun paymentChannelType(`value`: PaymentChannelType) {
        val toBeMapped = Either.ofRight<String, PaymentChannelType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paymentChannelType = mapped
    }

    /**
     * @param value The publisher id.
     */
    @JvmName("qhvncikrmqnfkcqr")
    public suspend fun publisherId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisherId = mapped
    }

    /**
     * @param value The environment in the publisher side for this resource.
     */
    @JvmName("fpljsoytqtqludqg")
    public suspend fun publisherTestEnvironment(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisherTestEnvironment = mapped
    }

    /**
     * @param value The seat count.
     */
    @JvmName("cadxkqshptbqcstx")
    public suspend fun quantity(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.quantity = mapped
    }

    /**
     * @param value The SaaS resource name.
     */
    @JvmName("gxmgdhhlbaknebiv")
    public suspend fun saasResourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.saasResourceName = mapped
    }

    /**
     * @param value The saas session id used for dev service migration request.
     */
    @JvmName("qfqebobfcvhsylek")
    public suspend fun saasSessionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.saasSessionId = mapped
    }

    /**
     * @param value The saas subscription id used for tenant to subscription level migration request.
     */
    @JvmName("lsuwqeamwknnnxnt")
    public suspend fun saasSubscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.saasSubscriptionId = mapped
    }

    /**
     * @param value The plan id.
     */
    @JvmName("mvuhjrrjqpsohult")
    public suspend fun skuId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.skuId = mapped
    }

    /**
     * @param value The current Term id.
     */
    @JvmName("mnqobwaicfhrbxaa")
    public suspend fun termId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.termId = mapped
    }

    internal fun build(): SaasCreationPropertiesArgs = SaasCreationPropertiesArgs(
        autoRenew = autoRenew,
        offerId = offerId,
        paymentChannelMetadata = paymentChannelMetadata,
        paymentChannelType = paymentChannelType,
        publisherId = publisherId,
        publisherTestEnvironment = publisherTestEnvironment,
        quantity = quantity,
        saasResourceName = saasResourceName,
        saasSessionId = saasSessionId,
        saasSubscriptionId = saasSubscriptionId,
        skuId = skuId,
        termId = termId,
    )
}
